##  Related Information
  * [Complete Modeling Example – SAP LeanIX as an Application](https://help.sap.com/docs/leanix/ea/general-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a3a157a441014a44fe44b7fc123f5__complete_modeling_example_sap_leanix_as_an_application)
  * Modeling guidelines for application subtypes:
    * [Microservice Modeling Guidelines](https://help.sap.com/docs/leanix/ea/microservice-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page covers modeling guidelines for microservices. Learn best practices for tracking their provisioning and dependencies effectively and avoid common antipatterns.")
    * [AI Agent Modeling Guidelines](https://help.sap.com/docs/leanix/ea/ai-agent-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Explore best practices for modeling AI agents and learn how to avoid common antipatterns.")
  * Modeling best practices for major IT systems:
    * [SAP Modeling Best Practices](https://help.sap.com/docs/leanix/ea/sap-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD "This modeling guide offers best practices for modeling SAP Cloud Solutions like S/4HANA and SAP BTP alongside legacy systems like SAP ERP 6.0.")
    * [Microsoft Applications Modeling Best Practices](https://help.sap.com/docs/leanix/ea/microsoft-applications-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD "This modeling guide offers best practices for modeling Microsoft solutions like Microsoft Azure, Microsoft Dynamics, and Microsoft Office 365.")
    * [Google Cloud Platform Modeling Best Practices](https://help.sap.com/docs/leanix/ea/google-cloud-platform-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD "This modeling guide offers best practices for modeling the services of the Google Cloud Platform \(GCP\) as an IaaS solution.")
    * [Salesforce Applications Modeling Best Practices](https://help.sap.com/docs/leanix/ea/salesforce-applications-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD "This modeling guide offers best practices for modeling Salesforce as a SaaS and a PaaS solution.")
    * [AWS Applications Modeling Best Practices](https://help.sap.com/docs/leanix/ea/aws-applications-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD "This modeling guide offers best practices for modeling Amazon Web Services \(AWS\).")
